bayespy.inference.vmp.nodes.beta.BetaMoments.compute_fixed_moments
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaMoments.compute_fixed_moments